# `royalnet.constellation`

The subpackage providing all functions and classes that handle the webserver and the webpages.

It requires the `constellation` extra to be installed ([`starlette`](https://github.com/encode/starlette)).

You can install it with:
```
pip install royalnet[constellation]
```

It optionally uses the `sentry` extra.

You can install it with:
```
pip install royalnet[constellation,sentry]
```